"""
SAbDab_get_structure

Get antibody structure details from SAbDab by PDB ID. Returns CDR annotations, chain information,...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def SAbDab_get_structure(
    operation: Optional[str] = None,
    pdb_id: Optional[str] = None,
    pdb_code: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get antibody structure details from SAbDab by PDB ID. Returns CDR annotations, chain information,...

    Parameters
    ----------
    operation : str

    pdb_id : str
        4-character PDB ID (e.g., 1IGT, 6W41). Alias: pdb_code.
    pdb_code : str
        Alias for pdb_id. 4-character PDB ID (e.g., 1IGT, 6W41).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {
            "operation": operation,
            "pdb_id": pdb_id,
            "pdb_code": pdb_code,
        }.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "SAbDab_get_structure",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["SAbDab_get_structure"]
